NMSC - Slip Opinions

New Mexico Supreme Court — Current Slip Opinions
| The slip opinion is the first version of an opinion released by the Chief Clerk of the Supreme Court. Once an opinion is selected for publication by the Court, it is assigned a vendor-neutral citation by the Chief Clerk for compliance with Rule 23-112 NMRA. The New Mexico Compilation Commission provides editorial services such as proofreading, applying court-approved corrections and topic indices. Once authenticated and formally published, the slip opinion is removed from the Slip Opinion page. Caution: The slip opinion may contain computer-generated errors or other deviations from the formal authenticated opinion. In case of discrepancies between a slip opinion and the authenticated formal opinion published under "Current Year Opinions" on this website, the authenticated opinion controls.
| Sorting options — The opinions may be sorted by "Filing Date", "Short Title", or "Docket No."
| Click on the column name/header — the opinions will sort in descending/ascending order.
| Note that the Short Title column contains the full text of the slip opinion in PDF format.
Filing Date | Short Title | Docket No.
--- | --- | ---
05/09/2013 | Moongate Water Co., Inc. v. City of Las Cruces | 33,182
05/13/2013 | Skidgel v. Hatch | 33,811
05/16/2013 | State v. Montoya | 32,279
05/30/2013 | Gonzalez v. Performance Painting, Inc. | 32,844
05/30/2013 | Flemma v. Halliburton Energy Services, Inc. | 33,353
06/03/2013 | N.M. Taxation & Revenue Dep't. v. Barnesandnoble.com, LLC | 33,627